==> puppet-6.21.1-1-any.pkg.tar.xz: opt/puppetlabs/puppet/vendor_modules/augeas_core/CHANGELOG.md <==
# Change log

All notable changes to this project will be documented in this file. The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/) and this project adheres to [Semantic Versioning](http://semver.org).

## [1.1.1](https://github.com/puppetlabs/puppetlabs-augeas_core/tree/1.1.1) (2020-09-29)

[Full Changelog](https://github.com/puppetlabs/puppetlabs-augeas_core/compare/1.1.0...1.1.1)

### Fixed

- \(maint\) Readd puppet-blacksmith dependency [\#30](https://github.com/puppetlabs/puppetlabs-augeas_core/pull/30) ([GabrielNagy](https://github.com/GabrielNagy))

## [1.1.0](https://github.com/puppetlabs/puppetlabs-augeas_core/tree/1.1.0) (2020-09-29)

[Full Changelog](https://github.com/puppetlabs/puppetlabs-augeas_core/compare/1.0.5...1.1.0)

### Added

- \(MODULES-7397\) Load Augeas lenses from modules [\#27](https://github.com/puppetlabs/puppetlabs-augeas_core/pull/27) ([luchihoratiu](https://github.com/luchihoratiu))

## [1.0.5](https://github.com/puppetlabs/puppetlabs-augeas_core/tree/1.0.5) (2019-10-31)

[Full Changelog](https://github.com/puppetlabs/puppetlabs-augeas_core/compare/1.0.4...1.0.5)

### Added

- pdksync - \(maint\) Update module using PDK 1.14.0 [\#21](https://github.com/puppetlabs/puppetlabs-augeas_core/pull/21) ([mihaibuzgau](https://github.com/mihaibuzgau))

## [1.0.4](https://github.com/puppetlabs/puppetlabs-augeas_core/tree/1.0.4) (2019-01-10)

[Full Changelog](https://github.com/puppetlabs/puppetlabs-augeas_core/compare/1.0.3...1.0.4)

### Added

- \(L10n\) Updating translations for readmes/README\_ja\_JP.md [\#16](https://github.com/puppetlabs/puppetlabs-augeas_core/pull/16) ([ehom](https://github.com/ehom))

## [1.0.3](https://github.com/puppetlabs/puppetlabs-augeas_core/tree/1.0.3) (2018-10-02)

[Full Changelog](https://github.com/puppetlabs/puppetlabs-augeas_core/compare/1.0.2...1.0.3)

### Added

- \(MODULES-8014\) relatively require helper code [\#9](https://github.com/puppetlabs/puppetlabs-augeas_core/pull/9) ([melissa](https://github.com/melissa))

## [1.0.2](https://github.com/puppetlabs/puppetlabs-augeas_core/tree/1.0.2) (2018-09-26)

[Full Changelog](https://github.com/puppetlabs/puppetlabs-augeas_core/compare/1.0.1...1.0.2)

### Fixed

- \(MODULES-7814\) Ignore nil values when parsing commands. Fix for: Could not evaluate: undefined method strip! for nil:NilClass [\#8](https://github.com/puppetlabs/puppetlabs-augeas_core/pull/8) ([Lavinia-Dan](https://github.com/Lavinia-Dan))

## [1.0.1](https://github.com/puppetlabs/puppetlabs-augeas_core/tree/1.0.1) (2018-08-17)

[Full Changelog](https://github.com/puppetlabs/puppetlabs-augeas_core/compare/1.0.0...1.0.1)

### Added

- \(PUP-9053\) Enable localization [\#5](https://github.com/puppetlabs/puppetlabs-augeas_core/pull/5) ([melissa](https://github.com/melissa))
- Include puppet 6 and remove default role [\#3](https://github.com/puppetlabs/puppetlabs-augeas_core/pull/3) ([joshcooper](https://github.com/joshcooper))
- \(maint\) Update beaker-puppet version to 0.16 [\#2](https://github.com/puppetlabs/puppetlabs-augeas_core/pull/2) ([melissa](https://github.com/melissa))
- Safely deserialize stringified array [\#1](https://github.com/puppetlabs/puppetlabs-augeas_core/pull/1) ([jhelwig](https://github.com/jhelwig))

## [1.0.0](https://github.com/puppetlabs/puppetlabs-augeas_core/tree/1.0.0) (2018-07-02)

[Full Changelog](https://github.com/puppetlabs/puppetlabs-augeas_core/compare/b9263341547f13a6af09f748d9b9ac483b5d2030...1.0.0)



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/skywinder/Github-Changelog-Generator)*

==> puppet-7.24.0-1-any.pkg.tar.xz: opt/puppetlabs/puppet/vendor_modules/augeas_core/CHANGELOG.md <==
# Change log

All notable changes to this project will be documented in this file. The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/) and this project adheres to [Semantic Versioning](http://semver.org).

## [1.2.0](https://github.com/puppetlabs/puppetlabs-augeas_core/tree/1.2.0) (2021-10-01)

[Full Changelog](https://github.com/puppetlabs/puppetlabs-augeas_core/compare/1.1.2...1.2.0)

### Added

- \(MODULES-11167\) \(MODULES-11191\) Add RockyLinux && AlmaLinux to augeas-core metadata [\#40](https://github.com/puppetlabs/puppetlabs-augeas_core/pull/40) ([BobosilaVictor](https://github.com/BobosilaVictor))

### Fixed

- \(MODULES-8183\) Fix ToC truncation in REFERENCE.md [\#42](https://github.com/puppetlabs/puppetlabs-augeas_core/pull/42) ([GabrielNagy](https://github.com/GabrielNagy))

## [1.1.2](https://github.com/puppetlabs/puppetlabs-augeas_core/tree/1.1.2) (2021-03-08)

[Full Changelog](https://github.com/puppetlabs/puppetlabs-augeas_core/compare/1.1.1...1.1.2)

### Fixed

- \(MODULES-10950\) Infer application name from run mode [\#37](https://github.com/puppetlabs/puppetlabs-augeas_core/pull/37) ([GabrielNagy](https://github.com/GabrielNagy))

## [1.1.1](https://github.com/puppetlabs/puppetlabs-augeas_core/tree/1.1.1) (2020-09-29)

[Full Changelog](https://github.com/puppetlabs/puppetlabs-augeas_core/compare/1.1.0...1.1.1)

### Fixed

- \(maint\) Readd puppet-blacksmith dependency [\#30](https://github.com/puppetlabs/puppetlabs-augeas_core/pull/30) ([GabrielNagy](https://github.com/GabrielNagy))

## [1.1.0](https://github.com/puppetlabs/puppetlabs-augeas_core/tree/1.1.0) (2020-09-29)

[Full Changelog](https://github.com/puppetlabs/puppetlabs-augeas_core/compare/1.0.5...1.1.0)

### Added

- \(MODULES-7397\) Load Augeas lenses from modules [\#27](https://github.com/puppetlabs/puppetlabs-augeas_core/pull/27) ([luchihoratiu](https://github.com/luchihoratiu))

## [1.0.5](https://github.com/puppetlabs/puppetlabs-augeas_core/tree/1.0.5) (2019-10-31)

[Full Changelog](https://github.com/puppetlabs/puppetlabs-augeas_core/compare/1.0.4...1.0.5)

### Added

- pdksync - \(maint\) Update module using PDK 1.14.0 [\#21](https://github.com/puppetlabs/puppetlabs-augeas_core/pull/21) ([mihaibuzgau](https://github.com/mihaibuzgau))

## [1.0.4](https://github.com/puppetlabs/puppetlabs-augeas_core/tree/1.0.4) (2019-01-10)

[Full Changelog](https://github.com/puppetlabs/puppetlabs-augeas_core/compare/1.0.3...1.0.4)

### Added

- \(L10n\) Updating translations for readmes/README\_ja\_JP.md [\#16](https://github.com/puppetlabs/puppetlabs-augeas_core/pull/16) ([ehom](https://github.com/ehom))

## [1.0.3](https://github.com/puppetlabs/puppetlabs-augeas_core/tree/1.0.3) (2018-10-02)

[Full Changelog](https://github.com/puppetlabs/puppetlabs-augeas_core/compare/1.0.2...1.0.3)

### Added

- \(MODULES-8014\) relatively require helper code [\#9](https://github.com/puppetlabs/puppetlabs-augeas_core/pull/9) ([melissa](https://github.com/melissa))

## [1.0.2](https://github.com/puppetlabs/puppetlabs-augeas_core/tree/1.0.2) (2018-09-26)

[Full Changelog](https://github.com/puppetlabs/puppetlabs-augeas_core/compare/1.0.1...1.0.2)

### Fixed

- \(MODULES-7814\) Ignore nil values when parsing commands. Fix for: Could not evaluate: undefined method strip! for nil:NilClass [\#8](https://github.com/puppetlabs/puppetlabs-augeas_core/pull/8) ([Lavinia-Dan](https://github.com/Lavinia-Dan))

## [1.0.1](https://github.com/puppetlabs/puppetlabs-augeas_core/tree/1.0.1) (2018-08-17)

[Full Changelog](https://github.com/puppetlabs/puppetlabs-augeas_core/compare/1.0.0...1.0.1)

### Added

- \(PUP-9053\) Enable localization [\#5](https://github.com/puppetlabs/puppetlabs-augeas_core/pull/5) ([melissa](https://github.com/melissa))
- Include puppet 6 and remove default role [\#3](https://github.com/puppetlabs/puppetlabs-augeas_core/pull/3) ([joshcooper](https://github.com/joshcooper))
- \(maint\) Update beaker-puppet version to 0.16 [\#2](https://github.com/puppetlabs/puppetlabs-augeas_core/pull/2) ([melissa](https://github.com/melissa))
- Safely deserialize stringified array [\#1](https://github.com/puppetlabs/puppetlabs-augeas_core/pull/1) ([jhelwig](https://github.com/jhelwig))

## [1.0.0](https://github.com/puppetlabs/puppetlabs-augeas_core/tree/1.0.0) (2018-07-02)

[Full Changelog](https://github.com/puppetlabs/puppetlabs-augeas_core/compare/b9263341547f13a6af09f748d9b9ac483b5d2030...1.0.0)



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
